package org.fuseri.moduleexercise.exercise;

import org.fuseri.model.dto.common.Result;
import org.fuseri.moduleexercise.common.DomainRepository;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageRequest;

/**
 * A repository interface for managing Exercise entities
 */
public interface ExerciseRepository extends DomainRepository<Exercise, String> {

    /**
     * Filters the exercises by the specified difficulty level and course id,
     * and returns a {@link Result} object containing these filtered exercises
     * along with pagination information
     *
     * @param pageRequest the pagination settings for the result
     * @param courseId    the id of the course to filter by
     * @param difficulty  the difficulty level to filter by
     * @return a {@link Result} object containing a list of paginated exercises that match the filter criteria
     */
    Page<Exercise> filterPerDifficultyPerCourse(PageRequest pageRequest, String courseId, int difficulty);
}
